@@ -31,40 +31,46 @@ LoadConfigFile(void)
   preferences.camprefs.overlay_type         = gnome_config_get_int("coriander/display/overlay_type=0");
   preferences.camprefs.overlay_pattern      = gnome_config_get_int("coriander/display/overlay_pattern=0");
   preferences.camprefs.display_redraw_rate  = gnome_config_get_float("coriander/display/redraw_rate=4.0");
-  preferences.camprefs.receive_method       = gnome_config_get_int("coriander/receive/method=0");
   preferences.camprefs.dma_buffer_size      = gnome_config_get_int("coriander/receive/dma_buffer_size=10");
-  preferences.camprefs.video1394_dropframes = gnome_config_get_int("coriander/receive/video1394_dropframes=0");
-  preferences.camprefs.save_scratch         = gnome_config_get_int("coriander/save/scratch=0");
+  preferences.camprefs.iso_nodrop           = gnome_config_get_int("coriander/receive/iso_nodrop=0");
+  preferences.camprefs.save_format          = gnome_config_get_int("coriander/save/format=0");
   preferences.camprefs.save_period          = gnome_config_get_int("coriander/save/period=1");
-  preferences.camprefs.save_convert         = gnome_config_get_int("coriander/save/convert=0");
-  preferences.camprefs.save_datenum         = gnome_config_get_int("coriander/save/datenum=1");
+  preferences.camprefs.save_append          = gnome_config_get_int("coriander/save/append=0");
+  preferences.camprefs.save_to_dir          = gnome_config_get_int("coriander/save/save_to_dir=0");
+  preferences.camprefs.save_to_stdout       = gnome_config_get_int("coriander/save/save_to_stdout=0");
   preferences.camprefs.use_ram_buffer       = gnome_config_get_int("coriander/save/use_ram_buffer=0");
   preferences.camprefs.ram_buffer_size      = gnome_config_get_int("coriander/save/ram_buffer_size=100");
-  preferences.camprefs.ftp_scratch          = gnome_config_get_int("coriander/ftp/scratch=0");
+  preferences.camprefs.ftp_mode             = gnome_config_get_int("coriander/ftp/mode=0");
   preferences.camprefs.ftp_period           = gnome_config_get_int("coriander/ftp/period=1");
   preferences.camprefs.ftp_datenum          = gnome_config_get_int("coriander/ftp/datenum=1");
   preferences.camprefs.v4l_period           = gnome_config_get_int("coriander/v4l/period=1");
-
-  //fprintf(stderr,"ftpuser orig adr: 0x%x\n",preferences.camprefs.video1394_device);
-  //preferences.camprefs.video1394_device=(char*)malloc(STRING_SIZE*sizeof(char));
-  //fprintf(stderr,"ftpuser orig adr: 0x%x\n",preferences.camprefs.video1394_device);
-  //sprintf(preferences.camprefs.video1394_device,"/dev/video1394/%d", dc1394_get_camera_port(camera->camera_info.handle));
-  preferences.camprefs.video1394_device = gnome_config_get_string("coriander/receive/video1394_device=/dev/video1394/0");
-
-  preferences.camprefs.save_filename = gnome_config_get_string("coriander/save/filename=test.jpg");
+  preferences.camprefs.broadcast            = gnome_config_get_int("coriander/global/broadcast=0");
+    
+  preferences.camprefs.save_filename    = gnome_config_get_string("coriander/save/filename=test");
   preferences.camprefs.overlay_filename = gnome_config_get_string("coriander/display/overlay_filename=test.png");
-  preferences.camprefs.ftp_filename  = gnome_config_get_string("coriander/ftp/filename=");
-  preferences.camprefs.ftp_path      = gnome_config_get_string("coriander/ftp/path=");
-  preferences.camprefs.ftp_address   = gnome_config_get_string("coriander/ftp/address=");
-  preferences.camprefs.ftp_user      = gnome_config_get_string("coriander/ftp/user=username");
-  preferences.camprefs.v4l_dev_name  = gnome_config_get_string("coriander/v4l/v4l_dev_name=/dev/video0");
-  preferences.camprefs.ftp_password = "";
+  preferences.camprefs.ftp_filename     = gnome_config_get_string("coriander/ftp/filename=");
+  preferences.camprefs.ftp_path         = gnome_config_get_string("coriander/ftp/path=");
+  preferences.camprefs.ftp_address      = gnome_config_get_string("coriander/ftp/address=");
+  preferences.camprefs.ftp_user         = gnome_config_get_string("coriander/ftp/user=username");
+  preferences.camprefs.v4l_dev_name     = gnome_config_get_string("coriander/v4l/v4l_dev_name=/dev/video0");
+  preferences.camprefs.ftp_password     = "";
+
+  preferences.op_timeout                = gnome_config_get_float("coriander/global/one_push_timeout=10.0");
+  preferences.auto_update               = gnome_config_get_int("coriander/global/auto_update=1");
+  preferences.auto_update_frequency     = gnome_config_get_float("coriander/global/auto_update_frequency=2.0");
+  preferences.overlay_byte_order        = gnome_config_get_int("coriander/global/overlay_byte_order=800");
+  // for compatibilty with older libdc
+  if (preferences.overlay_byte_order==0)
+    preferences.overlay_byte_order=DC1394_BYTE_ORDER_UYVY;
+  if (preferences.overlay_byte_order==1)
+    preferences.overlay_byte_order=DC1394_BYTE_ORDER_YUYV;
+  preferences.no_overwrite              = gnome_config_get_int("coriander/global/no_overwrite=1");
+  preferences.warning_in_popup          = gnome_config_get_int("coriander/global/warning_in_popup=0");
+  preferences.error_in_popup            = gnome_config_get_int("coriander/global/error_in_popup=1");
+  preferences.automate_receive          = gnome_config_get_int("coriander/global/automate_receive=1");
+  preferences.automate_iso              = gnome_config_get_int("coriander/global/automate_iso=1");
+  //fprintf(stderr,"Buffer size read as: %d\n",preferences.camprefs.ram_buffer_size);
 
-  preferences.op_timeout             = gnome_config_get_float("coriander/global/one_push_timeout=10.0");
-  preferences.auto_update            = gnome_config_get_int("coriander/global/auto_update=1");
-  preferences.auto_update_frequency  = gnome_config_get_float("coriander/global/auto_update_frequency=2.0");
-  preferences.sync_control           = gnome_config_get_float("coriander/global/sync_control=0");
-  preferences.overlay_byte_order     = gnome_config_get_int("coriander/global/overlay_byte_order=0");
 }
 
 void
@@ -81,17 +87,20 @@ CopyCameraPrefs(camera_t* cam) {
   cam->prefs.overlay_color_b        = preferences.camprefs.overlay_color_b;
   cam->prefs.overlay_type           = preferences.camprefs.overlay_type;
   cam->prefs.overlay_pattern        = preferences.camprefs.overlay_pattern;
-  cam->prefs.receive_method         = preferences.camprefs.receive_method;
-  cam->prefs.video1394_dropframes   = preferences.camprefs.video1394_dropframes;
+  cam->prefs.iso_nodrop             = preferences.camprefs.iso_nodrop;
   cam->prefs.dma_buffer_size        = preferences.camprefs.dma_buffer_size;
-  cam->prefs.save_scratch           = preferences.camprefs.save_scratch;
+  cam->prefs.save_format            = preferences.camprefs.save_format;
   cam->prefs.save_period            = preferences.camprefs.save_period;
-  cam->prefs.save_datenum           = preferences.camprefs.save_datenum;
+  cam->prefs.save_append            = preferences.camprefs.save_append;
+  cam->prefs.save_to_dir            = preferences.camprefs.save_to_dir;
+  cam->prefs.save_to_stdout         = preferences.camprefs.save_to_stdout;
+  cam->prefs.use_ram_buffer         = preferences.camprefs.use_ram_buffer;
   cam->prefs.ram_buffer_size        = preferences.camprefs.ram_buffer_size;
-  cam->prefs.ftp_scratch            = preferences.camprefs.ftp_scratch;
+  cam->prefs.ftp_mode               = preferences.camprefs.ftp_mode;
   cam->prefs.ftp_period             = preferences.camprefs.ftp_period;
   cam->prefs.ftp_datenum            = preferences.camprefs.ftp_datenum;
   cam->prefs.v4l_period             = preferences.camprefs.v4l_period;
+  cam->prefs.broadcast              = preferences.camprefs.broadcast;
   strcpy(cam->prefs.save_filename   , preferences.camprefs.save_filename);
   strcpy(cam->prefs.overlay_filename, preferences.camprefs.overlay_filename);
   strcpy(cam->prefs.ftp_filename    , preferences.camprefs.ftp_filename);
@@ -99,12 +108,14 @@ CopyCameraPrefs(camera_t* cam) {
   strcpy(cam->prefs.ftp_address     , preferences.camprefs.ftp_address);
   strcpy(cam->prefs.ftp_user        , preferences.camprefs.ftp_user);
   strcpy(cam->prefs.v4l_dev_name    , preferences.camprefs.v4l_dev_name);
-  strcpy(cam->prefs.video1394_device, preferences.camprefs.video1394_device);
   preferences.camprefs.ftp_password = "";
+  //fprintf(stderr,"Buffer size copied to: %d\n",cam->prefs.ram_buffer_size);
   
+
+  //FIXME: update for multi-unit cameras
   tmp=(char*)malloc(STRING_SIZE*sizeof(char));
-  sprintf(tmp,"coriander/camera_names/%llx=%s %s",cam->camera_info.euid_64,
-	  cam->camera_info.vendor, cam->camera_info.model);
+  sprintf(tmp,"coriander/camera_names/%llx=%s %s",cam->camera_info->guid,
+	  cam->camera_info->vendor, cam->camera_info->model);
   tmp_ptr=gnome_config_get_string(tmp);
   strcpy(cam->prefs.name,tmp_ptr);
   free(tmp);
