@@ -22,7 +22,6 @@ void
 UpdateFormat7Window(void)
 {
   UpdateFormat7Ranges();
-  UpdateFormat7BppRange();
   BuildFormat7ColorMenu();
   UpdateFormat7InfoFrame();
 }
@@ -45,7 +44,7 @@ UpdateCommanderWindow(void)
   UpdateTriggerFrame();
   UpdatePowerFrame();
   UpdateMemoryFrame();
-  UpdateFormatMenu();
+  //  UpdateFormatMenu();
   UpdateIsoFrame();
   UpdateOptionFrame();
   UpdateServiceFrame();
@@ -56,9 +55,11 @@ UpdateFeatureWindow(void)
 {
   int i;
 
-  for (i=FEATURE_MIN;i<=FEATURE_MAX;i++) {
-    if ((camera->feature_set.feature[i-FEATURE_MIN].available>0)&&
-	(i!=FEATURE_TRIGGER)) {
+  //char stemp[256];
+
+  for (i=DC1394_FEATURE_MIN;i<=DC1394_FEATURE_MAX;i++) {
+    if ((camera->feature_set.feature[i-DC1394_FEATURE_MIN].available>0)&&
+	(i!=DC1394_FEATURE_TRIGGER)) {
       UpdateRange(i);
     }
   }
